/// <reference types="react" />
import IdAllocator from './IdAllocator';
import * as typeIs from './typeIs';
export { IdAllocator, typeIs };
/** Helper type to extract an HTML element's valid props */
export declare type HTMLElementProps<Element extends keyof JSX.IntrinsicElements> = JSX.IntrinsicElements[Element] extends React.DetailedHTMLProps<infer Props, any> ? Props : never;
/**
 * Helper that constructs a type requiring at least one of the passed keys
 * to be present in the passed interface.
 *
 * Example
 * ```
 * interface ExampleInterface {
 *   alwaysRequired: boolean,
 *   sometimesRequired: boolean,
 *   requiredOtherTimes: boolean,
 * }
 *
 * type ExampleEither = Either<ExampleInterface, 'sometimesRequired' | 'requiredOtherTimes'>
 *
 * // The above is equivalent to:
 * interface SharedInExampleInterface {
 *   alwaysRequired: boolean,
 * }
 *
 * interface FirstIsRequired extends SharedInExampleInterface {
 *   sometimesRequired: boolean,
 *   requiredOtherTimes?: boolean,
 * }
 *
 * interface SecondIsRequired extends SharedInExampleInterface {
 *   sometimesRequired?: boolean,
 *   requiredOtherTimes: boolean,
 * }
 *
 * type EquivalentToExampleEither = FirstIsRequired | SecondIsRequired
 * ```
 */
export declare type Either<T, Keys extends keyof T = keyof T> = Omit<T, Keys> & {
    [K in Keys]-?: Required<Pick<T, K>> & Partial<Pick<T, Exclude<Keys, K>>>;
}[Keys];
/**
 * Helper that constructs mutually exclusive record types. Refer to tests for usage.
 */
export declare type OneOf<T1, T2> = (T1 & Partial<Record<Exclude<keyof T2, keyof T1>, never>>) | (T2 & Partial<Record<Exclude<keyof T1, keyof T2>, never>>);
/** Helper type to check if element is a specific React Component  */
export declare function isComponentType<T = React.ReactElement>(element: React.ReactNode, displayName: string): element is T;
/**
 * Utility for making it easier to couple a React Component to a css selector.
 * Useful when writing css selectors that rely on interactivity, i.e. :hover.
 * Example:
 *  const checkBoxWrapper = createDataProp('checkbox-wrapper');
 *  // Used as selector:
 *  css`&:hover ${checkboxWrapper.selector} { }`
 *  // Used on React Component
 *  <div {...checkboxWrapper.prop} />
 * @param {string} name Name of element we want to reference.
 */
export declare function createDataProp(name: string): {
    prop: {
        [x: string]: string;
    };
    selector: string;
};
/** Object mapping keyCodes to keys */
export declare const keyMap: {
    ArrowUp: number;
    ArrowDown: number;
    ArrowLeft: number;
    ArrowRight: number;
    Enter: number;
    Escape: number;
    Space: number;
    Tab: number;
};
/**
 * An enum of accepted values for the "aria-current" attribute, used for
 * indicating current/active state across several contexts.
 *
 * The values "false", the empty string, and an ommission of this attribute
 * are all treated identically by user agents and screen readers.
 *
 * W3C Recommendation: https://www.w3.org/TR/wai-aria-1.1/#aria-current
 */
export declare const AriaCurrentValue: {
    readonly Page: "page";
    readonly Step: "step";
    readonly Location: "location";
    readonly Date: "date";
    readonly Time: "time";
    readonly True: "true";
    readonly Unset: "false";
};
export declare type AriaCurrentValue = typeof AriaCurrentValue[keyof typeof AriaCurrentValue];
/**
 * Accepts a type as an argument and makes all of the keys of the type optional
 */
export declare type RecursivePartial<T> = {
    [P in keyof T]?: T[P] extends Array<infer U> ? Array<RecursivePartial<U>> : T[P] extends object ? RecursivePartial<T[P]> : T[P] extends infer U | undefined ? RecursivePartial<U> | undefined : T[P] extends infer U | null ? RecursivePartial<U> | null : T[P];
};
//# sourceMappingURL=index.d.ts.map